"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createDeleteTrashBinEntriesTask = void 0;
var _tasks = require("@webiny/tasks");
var _common = require("../common");
var _types = require("../../types");
const createDeleteTrashBinEntriesTask = () => {
  return (0, _tasks.createPrivateTaskDefinition)({
    id: _types.EntriesTask.DeleteTrashBinEntries,
    title: "Headless CMS - Delete trash bin entries",
    description: "Delete trash bin entries.",
    maxIterations: 2,
    run: async params => {
      const {
        response,
        isAborted
      } = params;
      try {
        if (isAborted()) {
          return response.aborted();
        }
        const {
          DeleteTrashBinEntries
        } = await import( /* webpackChunkName: "DeleteTrashBinEntries" */"./useCases/DeleteTrashBinEntries");
        const deleteTrashBinEntries = new DeleteTrashBinEntries();
        return await deleteTrashBinEntries.execute(params);
      } catch (ex) {
        return response.error(ex.message ?? "Error while executing DeleteTrashBinEntries task");
      }
    },
    onDone: async ({
      context,
      task
    }) => {
      /**
       * We want to clean all child tasks and logs, which have no errors.
       */
      const childTasksCleanup = new _common.ChildTasksCleanup();
      try {
        await childTasksCleanup.execute({
          context,
          task
        });
      } catch (ex) {
        console.error("Error while cleaning `DeleteTrashBinEntries` child tasks.", ex);
      }
    }
  });
};
exports.createDeleteTrashBinEntriesTask = createDeleteTrashBinEntriesTask;

//# sourceMappingURL=deleteTrashBinEntriesTask.js.map